@@ -31,10 +31,6 @@ class LsCommand(BuildGraphCommand):
         )
 
     def execute_with_graph(self, context: Context, graph: TaskGraph, args: BuildGraphCommand.Args) -> None:
-        if len(graph) == 0:
-            print("no tasks.", file=sys.stderr)
-            sys.exit(1)
-
         required_tasks = set(graph.tasks(targets_only=True))
         longest_name = max(map(len, (t.path for t in graph.tasks(all=True)))) + 1
 
@@ -51,11 +47,15 @@ class LsCommand(BuildGraphCommand):
             status = graph.get_status(task)
             if status is not None:
                 line.append(f"[{status_to_text(status)}]")
-            if task.description:
-                line.append(task.description)
+            description = task.get_description()
+            if description:
+                line.append(description)
             print("  " + " ".join(line))
 
-        for task in graph.tasks(all=True):
+        def sort_key(task: Task) -> str:
+            return task.path
+
+        for task in sorted(graph.tasks(all=True), key=sort_key):
             if isinstance(task, GroupTask):
                 continue
             _print_task(task)
@@ -64,7 +64,7 @@ class LsCommand(BuildGraphCommand):
         print(colored("Groups", "blue", attrs=["bold", "underline"]))
         print()
 
-        for task in graph.tasks(all=True):
+        for task in sorted(graph.tasks(all=True), key=sort_key):
             if not isinstance(task, GroupTask):
                 continue
             _print_task(task)
